@@ -4,7 +4,7 @@ from typing import List, Mapping, Union
 import networkx as nx
 import pandas as pd
 
-import log_datasets.datasets
+# import log_datasets.datasets
 from utils.window_utils import TumblingWindowCreator, SlidingWindowCreator, WindowsCreator
 
 
@@ -173,7 +173,15 @@ def create_position_embeddings(event_ids: list, include_last: bool) -> dict:
     return embeddings
 
 
-def create_networkx_graph(graph_dict: dict, positional_embeddings: dict, anomalous_logs: list):
+def create_one_hot_map_value(all_event_ids, event_id_fill):
+    one_hot_map_value = {}
+    for event_id in all_event_ids:
+        one_hot_map_value[event_id]=0.0
+    one_hot_map_value[event_id_fill]=1.0
+    return list(one_hot_map_value.values())
+
+
+def create_networkx_graph(graph_dict: dict, positional_embeddings: dict, anomalous_logs: list, all_event_ids: list):
     nodes = set()
     edges_list = []
     graph = nx.DiGraph()
@@ -185,7 +193,8 @@ def create_networkx_graph(graph_dict: dict, positional_embeddings: dict, anomalo
     for node in nodes:
         attributes = {'name': node}
         if len(positional_embeddings) > 0:
-            attributes['x'] = [positional_embeddings.get(node, -1)]
+            attributes['x'] = create_one_hot_map_value(all_event_ids, node)
+            attributes['x'].append(positional_embeddings.get(node, -1))
         if len(anomalous_logs) > 0:
             attributes['y'] = 1 if node in anomalous_logs else 0
         graph.add_node(node, **attributes)
@@ -246,27 +255,27 @@ def normalize_positional_embeddings(embeddings: dict):
         for node in embeddings.keys():
             embeddings[node]=0
 
-if __name__ == '__main__':
-    nova_dataset = log_datasets.datasets.NovaDataset("../../data")
-    nova_dataset.initialize_dataset()
+# if __name__ == '__main__':
+    # nova_dataset = log_datasets.datasets.NovaDataset("../../data")
+    # nova_dataset.initialize_dataset()
     # networkx_graphs = nova_dataset.create_networkx_graphs(window_type="sliding", window_size=60000, window_slide=3000,
     #                                                       test_id=2, include_last=True, include_all_event_ids=False,
     #                                                       include_positional_embeddings=True)
-
+    #
     # for graph in networkx_graphs:
-    #     print(graph.nodes.data(), graph.edges.data())
-    # graph_dicts = nova_dataset.create_graphs(window_type="sliding", window_size=60000, window_slide=3000, test_id=1,
-    #                                          include_last=True, include_all_event_ids=True)
-    # for graph_dict in graph_dicts:
-    #     print(graph_dict)
-    # # print(create_graph_as_dict("A,B,C,B,C,A,D".split(","), False, list()))
-    # # print(create_position_embeddings("A,B,C,B,C,A,D".split(","), False))
-
-    # logs = "A,B,C,B,C,A,D".split(",")
-    # graph_dict = create_graph_as_dict(logs, True)
-    # positional_embeddings = create_position_embeddings(logs, True)
-    # print(graph_dict)
-    # print(positional_embeddings)
-    # networkx_graph = create_networkx_graph(graph_dict, positional_embeddings)
-    # print(networkx_graph.nodes)
-    # print(networkx_graph.nodes.data())
+    #     print(graph.nodes.data())
+    # # graph_dicts = nova_dataset.create_graphs(window_type="sliding", window_size=60000, window_slide=3000, test_id=1,
+    # #                                          include_last=True, include_all_event_ids=True)
+    # # for graph_dict in graph_dicts:
+    # #     print(graph_dict)
+    # # # print(create_graph_as_dict("A,B,C,B,C,A,D".split(","), False, list()))
+    # # # print(create_position_embeddings("A,B,C,B,C,A,D".split(","), False))
+    #
+    # # logs = "A,B,C,B,C,A,D".split(",")
+    # # graph_dict = create_graph_as_dict(logs, True)
+    # # positional_embeddings = create_position_embeddings(logs, True)
+    # # print(graph_dict)
+    # # print(positional_embeddings)
+    # # networkx_graph = create_networkx_graph(graph_dict, positional_embeddings)
+    # # print(networkx_graph.nodes)
+    # # print(networkx_graph.nodes.data())
